@@ -1,5 +1,7 @@
 //! # Examples
 //!
+//! ## Derive
+//!
 //! ```no_run
 //! use clap::{IntoApp, Parser, Subcommand};
 //!
@@ -82,7 +84,11 @@
 use std::{ffi::OsString, path::PathBuf};
 
 /// A [`clap::ArgEnum`] for available shell completions.
+///
 /// # Examples
+///
+/// ## Derive
+///
 /// ```no_run
 /// use clap::{Parser, Subcommand};
 ///
@@ -100,7 +106,7 @@ use std::{ffi::OsString, path::PathBuf};
 ///     },
 /// }
 /// ```
-#[derive(clap::ArgEnum, Clone)]
+#[derive(clap::ArgEnum, Clone, Copy)]
 #[non_exhaustive]
 pub enum Shell {
     /// Bourne Again SHell (bash)
@@ -118,56 +124,54 @@ pub enum Shell {
     Zsh,
 }
 
-enum Generators {
-    Shell(clap_complete::Shell),
-    Fig(clap_complete_fig::Fig),
-}
-
-impl clap_complete::Generator for Generators {
+impl clap_complete::Generator for Shell {
     fn file_name(&self, name: &str) -> String {
         match self {
-            Generators::Shell(shell) => shell.file_name(name),
-            Generators::Fig(fig) => fig.file_name(name),
+            Shell::Bash => clap_complete::Shell::Bash.file_name(name),
+            Shell::Elvish => clap_complete::Shell::Elvish.file_name(name),
+            Shell::Fish => clap_complete::Shell::Fish.file_name(name),
+            Shell::PowerShell => clap_complete::Shell::PowerShell.file_name(name),
+            Shell::Zsh => clap_complete::Shell::Zsh.file_name(name),
+
+            Shell::Fig => clap_complete_fig::Fig.file_name(name),
         }
     }
 
     fn generate(&self, cmd: &clap::Command, buf: &mut dyn std::io::Write) {
         match self {
-            Generators::Shell(shell) => shell.generate(cmd, buf),
-            Generators::Fig(fig) => fig.generate(cmd, buf),
+            Shell::Bash => clap_complete::Shell::Bash.generate(cmd, buf),
+            Shell::Elvish => clap_complete::Shell::Elvish.generate(cmd, buf),
+            Shell::Fish => clap_complete::Shell::Fish.generate(cmd, buf),
+            Shell::PowerShell => clap_complete::Shell::PowerShell.generate(cmd, buf),
+            Shell::Zsh => clap_complete::Shell::Zsh.generate(cmd, buf),
+
+            Shell::Fig => clap_complete_fig::Fig.generate(cmd, buf),
         }
     }
 }
 
 impl Shell {
     #[must_use]
-    pub fn to_generator(&self) -> impl clap_complete::Generator {
-        match self {
-            Self::Bash => Generators::Shell(clap_complete::Shell::Bash),
-            Self::Elvish => Generators::Shell(clap_complete::Shell::Elvish),
-            Self::Fish => Generators::Shell(clap_complete::Shell::Fish),
-            Self::PowerShell => Generators::Shell(clap_complete::Shell::PowerShell),
-            Self::Zsh => Generators::Shell(clap_complete::Shell::Zsh),
-
-            Self::Fig => Generators::Fig(clap_complete_fig::Fig),
-        }
+    #[deprecated(since = "0.2.1", note = "`Shell` now implements `Generator`")]
+    pub fn to_generator(self) -> impl clap_complete::Generator {
+        self
     }
 
     /// See [`clap_complete::generate()`].
     pub fn generate<S>(
-        &self,
+        self,
         command: &mut clap::Command,
         bin_name: S,
         buffer: &mut dyn std::io::Write,
     ) where
         S: Into<String>,
     {
-        clap_complete::generate(self.to_generator(), command, bin_name, buffer)
+        clap_complete::generate(self, command, bin_name, buffer)
     }
 
     /// See [`clap_complete::generate_to()`].
     pub fn generate_to<S, T>(
-        &self,
+        self,
         command: &mut clap::Command,
         bin_name: S,
         out_dir: T,
@@ -176,7 +180,7 @@ impl Shell {
         S: Into<String>,
         T: Into<OsString>,
     {
-        clap_complete::generate_to(self.to_generator(), command, bin_name, out_dir)
+        clap_complete::generate_to(self, command, bin_name, out_dir)
     }
 }
 
@@ -197,6 +201,10 @@ mod tests {
         );
     }
     #[test]
+    fn check_casing_fig() {
+        assert_eq!(Shell::Fig.to_possible_value().unwrap().get_name(), "fig");
+    }
+    #[test]
     fn check_casing_fish() {
         assert_eq!(Shell::Fish.to_possible_value().unwrap().get_name(), "fish");
     }
@@ -211,10 +219,6 @@ mod tests {
     fn check_casing_zsh() {
         assert_eq!(Shell::Zsh.to_possible_value().unwrap().get_name(), "zsh");
     }
-    #[test]
-    fn check_casing_fig() {
-        assert_eq!(Shell::Fig.to_possible_value().unwrap().get_name(), "fig");
-    }
 
     #[test]
     fn check_order() {
